@@ -1,7 +1,7 @@
 from sphinx.util.compat import Directive
 
 from noseOfYeti.tokeniser import Tokeniser, TokeniserCodec, determine_imports
-import support import spec_options
+from support import spec_options
 
 def enable(app):
     config = app.builder.config.values
@@ -24,4 +24,4 @@ def setup(app):
         name = 'noy_%s' % option.replace('-', '_')
         app.add_config_value(name, default, 'html')
     
-    app.connect('builder-inited', enable)
\ No newline at end of file
+    app.connect('builder-inited', enable)
